@@ -44,10 +44,6 @@ class ThresholdEvaluator(evaluator.Evaluator):
     # for reporting/ingestion lag
     look_back = 1
 
-    # minimum number of datapoints within sliding window to
-    # avoid unknown state
-    quorum = 1
-
     @classmethod
     def _bound_duration(cls, alarm, constraints):
         """Bound the duration of the statistics query."""
@@ -108,13 +104,21 @@ class ThresholdEvaluator(evaluator.Evaluator):
         Ensure there is sufficient data for evaluation, transitioning to
         unknown otherwise.
         """
-        sufficient = len(statistics) >= self.quorum
+        sufficient = len(statistics) >= alarm.rule['evaluation_periods']
         if not sufficient and alarm.state != evaluator.UNKNOWN:
+            LOG.warn(_('Expecting %(expected)d datapoints but only get '
+                       '%(actual)d') % {
+                'expected': alarm.rule['evaluation_periods'],
+                'actual': len(statistics)})
+            # Reason is not same as log message because we want to keep
+            # consistent since thirdparty software may depend on old format.
             reason = _('%d datapoints are unknown') % alarm.rule[
                 'evaluation_periods']
+            last = None if not statistics else (
+                getattr(statistics[-1], alarm.rule['statistic']))
             reason_data = self._reason_data('unknown',
                                             alarm.rule['evaluation_periods'],
-                                            None)
+                                            last)
             self._refresh(alarm, evaluator.UNKNOWN, reason, reason_data)
         return sufficient
 
