@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Red Hat, Inc
+# Copyright 2013 Red Hat, Inc
 #
 # Authors: Eoghan Glynn <eglynn@redhat.com>
 #
@@ -20,10 +19,11 @@ import math
 import random
 import uuid
 
+from oslo.utils import timeutils
+
 from ceilometer.alarm import rpc as rpc_alarm
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
-from ceilometer.openstack.common import timeutils
 
 
 LOG = log.getLogger(__name__)
@@ -231,7 +231,7 @@ class PartitionCoordinator(object):
         created_alarms = list(set(alarms) - self.last_alarms)
         LOG.debug(_('newly created alarms %s') % created_alarms)
         sufficient_deletion = self._deletion_requires_rebalance(alarms)
-        if (assuming or sufficient_deletion or self.presence_changed):
+        if assuming or sufficient_deletion or self.presence_changed:
             still_ahead = self._distribute(alarms, rebalance=True)
         elif created_alarms:
             still_ahead = self._distribute(list(created_alarms),
@@ -241,7 +241,7 @@ class PartitionCoordinator(object):
             still_ahead = self.this < self.oldest
         self.last_alarms = set(alarms)
         LOG.info(_('%(this)s not overtaken as master? %(still_ahead)s') %
-                ({'this': self.this, 'still_ahead': still_ahead}))
+                 ({'this': self.this, 'still_ahead': still_ahead}))
         return still_ahead
 
     def check_mastership(self, eval_interval, api_client):
