@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012-2013 eNovance <licensing@enovance.com>
+# Copyright 2012-2013 eNovance <licensing@enovance.com>
 #
 # Author: Julien Danjou <julien@danjou.info>
 #
@@ -20,13 +19,15 @@ import socket
 
 import msgpack
 from oslo.config import cfg
+import oslo.messaging
+from oslo.utils import units
 
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer import dispatcher
+from ceilometer import messaging
+from ceilometer.openstack.common.gettextutils import _
+from ceilometer.openstack.common.gettextutils import _LE
 from ceilometer.openstack.common import log
-from ceilometer.openstack.common.rpc import dispatcher as rpc_dispatcher
-from ceilometer.openstack.common.rpc import service as rpc_service
-from ceilometer.openstack.common import units
-from ceilometer import service
+from ceilometer.openstack.common import service as os_service
 
 OPTS = [
     cfg.StrOpt('udp_address',
@@ -36,26 +37,51 @@ OPTS = [
     cfg.IntOpt('udp_port',
                default=4952,
                help='Port to which the UDP socket is bound.'),
+    cfg.BoolOpt('requeue_sample_on_dispatcher_error',
+                default=False,
+                help='Requeue the sample on the collector sample queue '
+                'when the collector fails to dispatch it. This is only valid '
+                'if the sample come from the notifier publisher'),
 ]
 
 cfg.CONF.register_opts(OPTS, group="collector")
-cfg.CONF.import_opt('rpc_backend', 'ceilometer.openstack.common.rpc')
-cfg.CONF.import_opt('metering_topic', 'ceilometer.publisher.rpc',
+cfg.CONF.import_opt('metering_topic', 'ceilometer.publisher.messaging',
                     group="publisher_rpc")
+cfg.CONF.import_opt('metering_topic', 'ceilometer.publisher.messaging',
+                    group="publisher_notifier")
 
 
 LOG = log.getLogger(__name__)
 
 
-class CollectorService(service.DispatchedService, rpc_service.Service):
+class CollectorService(os_service.Service):
     """Listener for the collector service."""
-
     def start(self):
         """Bind the UDP socket and handle incoming data."""
+        # ensure dispatcher is configured before starting other services
+        self.dispatcher_manager = dispatcher.load_dispatcher_manager()
+        self.rpc_server = None
+        self.notification_server = None
+        super(CollectorService, self).start()
+
         if cfg.CONF.collector.udp_address:
             self.tg.add_thread(self.start_udp)
-        if cfg.CONF.rpc_backend:
-            super(CollectorService, self).start()
+
+        allow_requeue = cfg.CONF.collector.requeue_sample_on_dispatcher_error
+        transport = messaging.get_transport(optional=True)
+        if transport:
+            self.rpc_server = messaging.get_rpc_server(
+                transport, cfg.CONF.publisher_rpc.metering_topic, self)
+
+            target = oslo.messaging.Target(
+                topic=cfg.CONF.publisher_notifier.metering_topic)
+            self.notification_server = messaging.get_notification_listener(
+                transport, [target], [self],
+                allow_requeue=allow_requeue)
+
+            self.rpc_server.start()
+            self.notification_server.start()
+
             if not cfg.CONF.collector.udp_address:
                 # Add a dummy thread to have wait() working
                 self.tg.add_timer(604800, lambda: None)
@@ -72,7 +98,7 @@ class CollectorService(service.DispatchedService, rpc_service.Service):
             # enough for anybody.
             data, source = udp.recvfrom(64 * units.Ki)
             try:
-                sample = msgpack.loads(data)
+                sample = msgpack.loads(data, encoding='utf-8')
             except Exception:
                 LOG.warn(_("UDP: Cannot decode data sent by %s"), str(source))
             else:
@@ -85,17 +111,28 @@ class CollectorService(service.DispatchedService, rpc_service.Service):
 
     def stop(self):
         self.udp_run = False
+        if self.rpc_server:
+            self.rpc_server.stop()
+        if self.notification_server:
+            self.notification_server.stop()
         super(CollectorService, self).stop()
 
-    def initialize_service_hook(self, service):
-        '''Consumers must be declared before consume_thread start.'''
-        # Set ourselves up as a separate worker for the metering data,
-        # since the default for service is to use create_consumer().
-        self.conn.create_worker(
-            cfg.CONF.publisher_rpc.metering_topic,
-            rpc_dispatcher.RpcDispatcher([self]),
-            'ceilometer.collector.' + cfg.CONF.publisher_rpc.metering_topic,
-        )
+    def sample(self, ctxt, publisher_id, event_type, payload, metadata):
+        """RPC endpoint for notification messages
+
+        When another service sends a notification over the message
+        bus, this method receives it.
+
+        """
+        try:
+            self.dispatcher_manager.map_method('record_metering_data',
+                                               data=payload)
+        except Exception:
+            if cfg.CONF.collector.requeue_sample_on_dispatcher_error:
+                LOG.exception(_LE("Dispatcher failed to handle the sample, "
+                                  "requeue it."))
+                return oslo.messaging.NotificationResult.REQUEUE
+            raise
 
     def record_metering_data(self, context, data):
         """RPC endpoint for messages we send to ourselves.
@@ -103,5 +140,4 @@ class CollectorService(service.DispatchedService, rpc_service.Service):
         When the notification messages are re-published through the
         RPC publisher, this method receives them for processing.
         """
-        self.dispatcher_manager.map_method('record_metering_data',
-                                           data=data)
+        self.dispatcher_manager.map_method('record_metering_data', data=data)
