@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2014 Red Hat, Inc
+# Copyright 2014 Red Hat, Inc
 #
 # Author: Eoghan Glynn <eglynn@redhat.com>
 #
@@ -21,15 +20,29 @@ from oslo.config import cfg
 from ceilometer import nova_client
 from ceilometer import plugin
 
+OPTS = [
+    cfg.BoolOpt('workload_partitioning',
+                default=False,
+                help='Enable work-load partitioning, allowing multiple '
+                     'compute agents to be run simultaneously.')
+]
+cfg.CONF.register_opts(OPTS, group='compute')
+
 
 class InstanceDiscovery(plugin.DiscoveryBase):
     def __init__(self):
         super(InstanceDiscovery, self).__init__()
         self.nova_cli = nova_client.Client()
 
-    def discover(self, param=None):
-        """Discover resources to monitor.
-        """
+    def discover(self, manager, param=None):
+        """Discover resources to monitor."""
         instances = self.nova_cli.instance_get_all_by_host(cfg.CONF.host)
         return [i for i in instances
                 if getattr(i, 'OS-EXT-STS:vm_state', None) != 'error']
+
+    @property
+    def group_id(self):
+        if cfg.CONF.compute.workload_partitioning:
+            return cfg.CONF.host
+        else:
+            return None
