@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Intel
+# Copyright 2013 Intel
 #
 # Author: Shuangtai Tian <shuangtai.tian@intel.com>
 #
@@ -17,6 +16,7 @@
 # under the License.
 
 from oslo.config import cfg
+import oslo.messaging
 
 from ceilometer import plugin
 
@@ -33,13 +33,12 @@ cfg.CONF.register_opts(OPTS)
 
 class ComputeNotificationBase(plugin.NotificationBase):
     @staticmethod
-    def get_exchange_topics(conf):
-        """Return a sequence of ExchangeTopics defining the exchange and
-        topics to be connected for this plugin.
+    def get_targets(conf):
+        """Return a sequence of oslo.messaging.Target
+
+        This sequence is defining the exchange and topics to be connected for
+        this plugin.
         """
-        return [
-            plugin.ExchangeTopics(
-                exchange=conf.nova_control_exchange,
-                topics=set(topic + ".info"
-                           for topic in conf.notification_topics)),
-        ]
+        return [oslo.messaging.Target(topic=topic,
+                                      exchange=conf.nova_control_exchange)
+                for topic in conf.notification_topics]
