@@ -61,9 +61,9 @@ class _Base(plugin.ComputePollster):
 
     CACHE_KEY_DISK = 'diskio'
 
-    def _populate_cache(self, inspector, cache, instance, instance_name):
+    def _populate_cache(self, inspector, cache, instance):
         i_cache = cache.setdefault(self.CACHE_KEY_DISK, {})
-        if instance_name not in i_cache:
+        if instance.id not in i_cache:
             r_bytes = 0
             r_requests = 0
             w_bytes = 0
@@ -72,7 +72,7 @@ class _Base(plugin.ComputePollster):
             per_device_read_requests = {}
             per_device_write_bytes = {}
             per_device_write_requests = {}
-            for disk, info in inspector.inspect_disks(instance_name):
+            for disk, info in inspector.inspect_disks(instance):
                 LOG.debug(self.DISKIO_USAGE_MESSAGE,
                           instance, disk.device, info.read_requests,
                           info.read_bytes, info.write_requests,
@@ -92,14 +92,14 @@ class _Base(plugin.ComputePollster):
                 'write_bytes': per_device_write_bytes,
                 'write_requests': per_device_write_requests,
             }
-            i_cache[instance_name] = DiskIOData(
+            i_cache[instance.id] = DiskIOData(
                 r_bytes=r_bytes,
                 r_requests=r_requests,
                 w_bytes=w_bytes,
                 w_requests=w_requests,
                 per_disk_requests=per_device_requests,
             )
-        return i_cache[instance_name]
+        return i_cache[instance.id]
 
     @abc.abstractmethod
     def _get_samples(instance, c_data):
@@ -113,7 +113,6 @@ class _Base(plugin.ComputePollster):
                     manager.inspector,
                     cache,
                     instance,
-                    instance_name,
                 )
                 for s in self._get_samples(instance, c_data):
                     yield s
