@@ -12,11 +12,11 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
+import ceilometer
 from ceilometer.compute import plugin
 from ceilometer.compute.pollsters import util
 from ceilometer.compute.virt import inspector as virt_inspector
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
 from ceilometer import sample
 
@@ -45,10 +45,11 @@ class MemoryUsagePollster(plugin.ComputePollster):
             except virt_inspector.InstanceNotFoundException as err:
                 # Instance was deleted while getting samples. Ignore it.
                 LOG.debug(_('Exception while getting samples %s'), err)
-            except NotImplementedError:
+            except ceilometer.NotImplementedError:
                 # Selected inspector does not implement this pollster.
                 LOG.debug(_('Obtaining Memory Usage is not implemented for %s'
                             ), manager.inspector.__class__.__name__)
             except Exception as err:
-                LOG.error(_('Could not get Memory Usage for %(id)s: %(e)s'), (
-                          {'id': instance.id, 'e': err}))
+                LOG.exception(_('Could not get Memory Usage for '
+                                '%(id)s: %(e)s'), {'id': instance.id,
+                                                   'e': err})
