@@ -1,7 +1,6 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 eNovance <licensing@enovance.com>
-# Copyright © 2012 Red Hat, Inc
+# Copyright 2012 eNovance <licensing@enovance.com>
+# Copyright 2012 Red Hat, Inc
 #
 # Author: Julien Danjou <julien@danjou.info>
 # Author: Eoghan Glynn <eglynn@redhat.com>
@@ -17,9 +16,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from oslo.utils import timeutils
 
 from ceilometer.compute import util as compute_util
-from ceilometer.openstack.common import timeutils
 from ceilometer import sample
 
 
@@ -36,24 +35,29 @@ INSTANCE_PROPERTIES = [
 
 
 def _get_metadata_from_object(instance):
-    """Return a metadata dictionary for the instance.
-    """
+    """Return a metadata dictionary for the instance."""
     metadata = {
         'display_name': instance.name,
         'name': getattr(instance, 'OS-EXT-SRV-ATTR:instance_name', u''),
         'instance_type': (instance.flavor['id'] if instance.flavor else None),
         'host': instance.hostId,
         'flavor': instance.flavor,
-        # Image properties
-        'image': instance.image,
-        'image_ref': (instance.image['id'] if instance.image else None),
+        'status': instance.status.lower(),
     }
 
-    # Images that come through the conductor API in the nova notifier
-    # plugin will not have links.
-    if instance.image and instance.image.get('links'):
-        metadata['image_ref_url'] = instance.image['links'][0]['href']
+    # Image properties
+    if instance.image:
+        metadata['image'] = instance.image
+        metadata['image_ref'] = instance.image['id']
+        # Images that come through the conductor API in the nova notifier
+        # plugin will not have links.
+        if instance.image.get('links'):
+            metadata['image_ref_url'] = instance.image['links'][0]['href']
+        else:
+            metadata['image_ref_url'] = None
     else:
+        metadata['image'] = None
+        metadata['image_ref'] = None
         metadata['image_ref_url'] = None
 
     for name in INSTANCE_PROPERTIES:
@@ -64,14 +68,15 @@ def _get_metadata_from_object(instance):
     metadata['memory_mb'] = instance.flavor['ram']
     metadata['disk_gb'] = instance.flavor['disk']
     metadata['ephemeral_gb'] = instance.flavor['ephemeral']
-    metadata['root_gb'] = int(metadata['disk_gb']) - \
-        int(metadata['ephemeral_gb'])
+    metadata['root_gb'] = (int(metadata['disk_gb']) -
+                           int(metadata['ephemeral_gb']))
 
     return compute_util.add_reserved_user_metadata(instance.metadata, metadata)
 
 
 def make_sample_from_instance(instance, name, type, unit, volume,
-                              additional_metadata={}):
+                              resource_id=None, additional_metadata=None):
+    additional_metadata = additional_metadata or {}
     resource_metadata = _get_metadata_from_object(instance)
     resource_metadata.update(additional_metadata)
     return sample.Sample(
@@ -81,7 +86,7 @@ def make_sample_from_instance(instance, name, type, unit, volume,
         volume=volume,
         user_id=instance.user_id,
         project_id=instance.tenant_id,
-        resource_id=instance.id,
+        resource_id=resource_id or instance.id,
         timestamp=timeutils.isotime(),
         resource_metadata=resource_metadata,
     )
