@@ -19,10 +19,12 @@
 from oslo.config import cfg
 from oslo.utils import units
 
+from ceilometer.compute.pollsters import util
 from ceilometer.compute.virt.hyperv import utilsv2
 from ceilometer.compute.virt import inspector as virt_inspector
 from ceilometer.openstack.common import log
 
+
 CONF = cfg.CONF
 LOG = log.getLogger(__name__)
 
@@ -39,7 +41,8 @@ class HyperVInspector(virt_inspector.Inspector):
                 name=element_name,
                 UUID=name)
 
-    def inspect_cpus(self, instance_name):
+    def inspect_cpus(self, instance):
+        instance_name = util.instance_name(instance)
         (cpu_clock_used,
          cpu_count, uptime) = self._utils.get_cpu_metrics(instance_name)
         host_cpu_clock, host_cpu_count = self._utils.get_host_cpu_info()
@@ -51,7 +54,8 @@ class HyperVInspector(virt_inspector.Inspector):
 
         return virt_inspector.CPUStats(number=cpu_count, time=cpu_time)
 
-    def inspect_vnics(self, instance_name):
+    def inspect_vnics(self, instance):
+        instance_name = util.instance_name(instance)
         for vnic_metrics in self._utils.get_vnic_metrics(instance_name):
             interface = virt_inspector.Interface(
                 name=vnic_metrics["element_name"],
@@ -67,13 +71,10 @@ class HyperVInspector(virt_inspector.Inspector):
 
             yield (interface, stats)
 
-    def inspect_disks(self, instance_name):
+    def inspect_disks(self, instance):
+        instance_name = util.instance_name(instance)
         for disk_metrics in self._utils.get_disk_metrics(instance_name):
-            device = dict([(i, disk_metrics[i])
-                          for i in ['instance_id', 'host_resource']
-                          if i in disk_metrics])
-
-            disk = virt_inspector.Disk(device=device)
+            disk = virt_inspector.Disk(device=disk_metrics['instance_id'])
             stats = virt_inspector.DiskStats(
                 read_requests=0,
                 # Return bytes
