@@ -20,6 +20,7 @@ from lxml import etree
 from oslo.config import cfg
 import six
 
+from ceilometer.compute.pollsters import util
 from ceilometer.compute.virt import inspector as virt_inspector
 from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log as logging
@@ -82,9 +83,10 @@ class LibvirtInspector(virt_inspector.Inspector):
         return self.connection
 
     @retry_on_disconnect
-    def _lookup_by_name(self, instance_name):
+    def _lookup_by_uuid(self, instance):
+        instance_name = util.instance_name(instance)
         try:
-            return self._get_connection().lookupByName(instance_name)
+            return self._get_connection().lookupByUUIDString(instance.id)
         except Exception as ex:
             if not libvirt or not isinstance(ex, libvirt.libvirtError):
                 raise virt_inspector.InspectorException(six.text_type(ex))
@@ -93,9 +95,11 @@ class LibvirtInspector(virt_inspector.Inspector):
                 ex.get_error_domain() in (libvirt.VIR_FROM_REMOTE,
                                           libvirt.VIR_FROM_RPC)):
                 raise
-            msg = ("Error from libvirt while looking up %(instance_name)s: "
+            msg = ("Error from libvirt while looking up instance Name "
+                   "%(instance_name)s UUID %(instance_uuid)s: "
                    "[Error Code %(error_code)s] "
                    "%(ex)s" % {'instance_name': instance_name,
+                               'instance_uuid': instance.id,
                                'error_code': error_code,
                                'ex': ex})
             raise virt_inspector.InstanceNotFoundException(msg)
@@ -117,18 +121,21 @@ class LibvirtInspector(virt_inspector.Inspector):
                         # Instance was deleted while listing... ignore it
                         pass
 
-    def inspect_cpus(self, instance_name):
-        domain = self._lookup_by_name(instance_name)
+    def inspect_cpus(self, instance):
+        domain = self._lookup_by_uuid(instance)
         dom_info = domain.info()
         return virt_inspector.CPUStats(number=dom_info[3], time=dom_info[4])
 
-    def inspect_vnics(self, instance_name):
-        domain = self._lookup_by_name(instance_name)
+    def inspect_vnics(self, instance):
+        instance_name = util.instance_name(instance)
+        domain = self._lookup_by_uuid(instance)
         state = domain.info()[0]
         if state == libvirt.VIR_DOMAIN_SHUTOFF:
-            LOG.warn(_('Failed to inspect vnics of %(instance_name)s, '
+            LOG.warn(_('Failed to inspect vnics of instance Name '
+                       '%(instance_name)s UUID %(instance_uuid)s, '
                        'domain is in state of SHUTOFF'),
-                     {'instance_name': instance_name})
+                     {'instance_name': instance_name,
+                      'instance_uuid': instance.id})
             return
         tree = etree.fromstring(domain.XMLDesc(0))
         for iface in tree.findall('devices/interface'):
@@ -157,13 +164,16 @@ class LibvirtInspector(virt_inspector.Inspector):
                                                   tx_packets=dom_stats[5])
             yield (interface, stats)
 
-    def inspect_disks(self, instance_name):
-        domain = self._lookup_by_name(instance_name)
+    def inspect_disks(self, instance):
+        instance_name = util.instance_name(instance)
+        domain = self._lookup_by_uuid(instance)
         state = domain.info()[0]
         if state == libvirt.VIR_DOMAIN_SHUTOFF:
-            LOG.warn(_('Failed to inspect disks of %(instance_name)s, '
+            LOG.warn(_('Failed to inspect disks of instance Name '
+                       '%(instance_name)s UUID %(instance_uuid)s, '
                        'domain is in state of SHUTOFF'),
-                     {'instance_name': instance_name})
+                     {'instance_name': instance_name,
+                      'instance_uuid': instance.id})
             return
         tree = etree.fromstring(domain.XMLDesc(0))
         for device in filter(
