@@ -1,6 +1,8 @@
 # Copyright 2014 Intel Corporation.
 # All Rights Reserved.
 #
+# Author: Zhai Edwin <edwin.zhai@intel.com>
+#
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -14,5 +16,9 @@
 #    under the License.
 
 
+class NodeManagerException(Exception):
+    pass
+
+
 class IPMIException(Exception):
     pass
