@@ -25,6 +25,7 @@ from ceilometer.openstack.common import log
 
 
 CONF = cfg.CONF
+CONF.import_opt('http_timeout', 'ceilometer.service')
 
 
 LOG = log.getLogger(__name__)
@@ -170,7 +171,8 @@ class Client():
         req_params = {
             'headers': {
                 'Accept': 'application/json'
-            }
+            },
+            'timeout': CONF.http_timeout,
         }
 
         auth_way = params.get('auth')
