@@ -12,16 +12,15 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
+from oslo.utils import timeutils
 import six
 from six import moves
-from six.moves.urllib import parse as url_parse
+from six.moves.urllib import parse as urlparse
 
 from ceilometer.network.statistics import driver
 from ceilometer.network.statistics.opendaylight import client
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
-from ceilometer.openstack.common import timeutils
 from ceilometer import utils
 
 
@@ -43,7 +42,7 @@ def _get_properties(properties, prefix='properties'):
 def _get_int_sample(key, statistic, resource_id, resource_meta):
     if key not in statistic:
         return None
-    return (int(statistic[key]), resource_id, resource_meta)
+    return int(statistic[key]), resource_id, resource_meta
 
 
 class OpenDayLightDriver(driver.Driver):
@@ -51,33 +50,36 @@ class OpenDayLightDriver(driver.Driver):
 
     This driver uses resources in "pipeline.yaml".
     Resource requires below conditions:
+
     * resource is url
     * scheme is "opendaylight"
 
     This driver can be configured via query parameters.
     Supported parameters:
+
     * scheme:
-        The scheme of request url to OpenDaylight REST API endpoint.
-        (default http)
+      The scheme of request url to OpenDaylight REST API endpoint.
+      (default http)
     * auth:
-        Auth strategy of http.
-        This parameter can be set basic and digest.(default None)
+      Auth strategy of http.
+      This parameter can be set basic and digest.(default None)
     * user:
-        This is username that is used by auth.(default None)
+      This is username that is used by auth.(default None)
     * password:
-        This is password that is used by auth.(default None)
+      This is password that is used by auth.(default None)
     * container_name:
-        Name of container of OpenDaylight.(default "default")
-        This parameter allows multi vaues.
+      Name of container of OpenDaylight.(default "default")
+      This parameter allows multi vaues.
 
-    e.g.
-        opendaylight://127.0.0.1:8080/controller/nb/v2?container_name=default&
-            container_name=egg&auth=basic&user=admin&password=admin&scheme=http
+    e.g.::
 
-        In this case, the driver send request to below URL:
-            http://127.0.0.1:8080/controller/nb/v2/statistics/default/flow
-            and
-            http://127.0.0.1:8080/controller/nb/v2/statistics/egg/flow
+      opendaylight://127.0.0.1:8080/controller/nb/v2?container_name=default&
+      container_name=egg&auth=basic&user=admin&password=admin&scheme=http
+
+    In this case, the driver send request to below URLs:
+
+      http://127.0.0.1:8080/controller/nb/v2/statistics/default/flow
+      http://127.0.0.1:8080/controller/nb/v2/statistics/egg/flow
     """
     @staticmethod
     def _prepare_cache(endpoint, params, cache):
@@ -154,10 +156,10 @@ class OpenDayLightDriver(driver.Driver):
                     user_links.append(user_link)
 
                 # get link status to hosts
-                container_data['active_hosts'] = cs.host_tracker.\
-                    get_active_hosts(container_name)
-                container_data['inactive_hosts'] = cs.host_tracker.\
-                    get_inactive_hosts(container_name)
+                container_data['active_hosts'] = (
+                    cs.host_tracker.get_active_hosts(container_name))
+                container_data['inactive_hosts'] = (
+                    cs.host_tracker.get_inactive_hosts(container_name))
 
                 container_data['timestamp'] = timeutils.isotime()
 
@@ -184,13 +186,13 @@ class OpenDayLightDriver(driver.Driver):
             # OpenDaylight REST API has not api to getting meter.
             return None
 
-        parts = url_parse.ParseResult(params.get('scheme', ['http'])[0],
-                                      parse_url.netloc,
-                                      parse_url.path,
-                                      None,
-                                      None,
-                                      None)
-        endpoint = url_parse.urlunparse(parts)
+        parts = urlparse.ParseResult(params.get('scheme', ['http'])[0],
+                                     parse_url.netloc,
+                                     parse_url.path,
+                                     None,
+                                     None,
+                                     None)
+        endpoint = urlparse.urlunparse(parts)
 
         data = self._prepare_cache(endpoint, params, cache)
 
@@ -232,7 +234,7 @@ class OpenDayLightDriver(driver.Driver):
 
         resource_meta.update(_get_properties(statistic.get('properties')))
 
-        return (1, resource_id, resource_meta)
+        return 1, resource_id, resource_meta
 
     @staticmethod
     def _iter_port(extractor, data):
@@ -305,7 +307,7 @@ class OpenDayLightDriver(driver.Driver):
 
                 break
 
-        return (1, resource_id, resource_meta)
+        return 1, resource_id, resource_meta
 
     @staticmethod
     def _switch_port_receive_packets(statistic, resource_id,
@@ -390,7 +392,7 @@ class OpenDayLightDriver(driver.Driver):
 
     @staticmethod
     def _switch_table(statistic, resource_id, resource_meta):
-        return (1, resource_id, resource_meta)
+        return 1, resource_id, resource_meta
 
     @staticmethod
     def _switch_table_active_entries(statistic, resource_id,
@@ -425,7 +427,7 @@ class OpenDayLightDriver(driver.Driver):
 
     @staticmethod
     def _switch_flow(statistic, resource_id, resource_meta):
-        return (1, resource_id, resource_meta)
+        return 1, resource_id, resource_meta
 
     @staticmethod
     def _switch_flow_duration_seconds(statistic, resource_id,
