@@ -1,7 +1,6 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Intel Corp.
-# Copyright © 2013 eNovance
+# Copyright 2013 Intel Corp.
+# Copyright 2013-2014 eNovance
 #
 # Author: Yunhong Jiang <yunhong.jiang@intel.com>
 #         Julien Danjou <julien@danjou.info>
@@ -20,11 +19,10 @@
 
 import abc
 
+from oslo.utils import netutils
 import six
 from stevedore import driver
 
-from ceilometer.openstack.common import network_utils
-
 
 def get_publisher(url, namespace='ceilometer.publisher'):
     """Get publisher driver and load it.
@@ -32,7 +30,7 @@ def get_publisher(url, namespace='ceilometer.publisher'):
     :param URL: URL for the publisher
     :param namespace: Namespace to use to look for drivers.
     """
-    parse_result = network_utils.urlsplit(url)
+    parse_result = netutils.urlsplit(url)
     loaded_driver = driver.DriverManager(namespace, parse_result.scheme)
     return loaded_driver.driver(parse_result)
 
@@ -46,4 +44,4 @@ class PublisherBase(object):
 
     @abc.abstractmethod
     def publish_samples(self, context, samples):
-        "Publish samples into final conduit."
+        """Publish samples into final conduit."""
