@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 #
 # Copyright 2013 IBM Corp
 #
@@ -18,9 +17,10 @@
 
 import logging
 import logging.handlers
-import six.moves.urllib.parse as urlparse
 
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from six.moves.urllib import parse as urlparse
+
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
 from ceilometer import publisher
 
@@ -35,8 +35,9 @@ class FilePublisher(publisher.PublisherBase):
     If a file name and location is not specified, this File Publisher will not
     log any meters other than log a warning in Ceilometer log file.
 
-    To enable this publisher, add the following section to file
-    /etc/ceilometer/publisher.yaml or simply add it to an existing pipeline.
+    To enable this publisher, add the following section to the
+    /etc/ceilometer/publisher.yaml file or simply add it to an existing
+    pipeline::
 
         -
             name: meter_file
