@@ -10,17 +10,17 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-"""This is a very crude version of "in-memory HBase", which implements just
+""" This is a very crude version of "in-memory HBase", which implements just
  enough functionality of HappyBase API to support testing of our driver.
 """
 
 import copy
 import re
-
-from oslo_log import log
 import six
 
 import ceilometer
+from ceilometer.openstack.common.gettextutils import _
+from ceilometer.openstack.common import log
 
 LOG = log.getLogger(__name__)
 
@@ -214,12 +214,8 @@ class MTable(object):
         """
         op = args[0]
         value = args[1]
-        is_regex = False
         if value.startswith('binaryprefix:'):
             value = value[len('binaryprefix:'):]
-        if value.startswith('regexstring:'):
-            value = value[len('regexstring:'):]
-            is_regex = True
         column = 'f:' + value
         r = {}
         for row in rows:
@@ -230,8 +226,7 @@ class MTable(object):
                         (op == '>=' and key >= column) or
                         (op == '<=' and key <= column) or
                         (op == '>' and key > column) or
-                        (op == '<' and key < column) or
-                        (is_regex and re.search(value, key))):
+                        (op == '<' and key < column)):
                     r_data[key] = data[key]
                 else:
                     raise ceilometer.NotImplementedError(
@@ -262,9 +257,8 @@ class MConnection(object):
     def __exit__(self, exc_type, exc_val, exc_tb):
         pass
 
-    @staticmethod
-    def open():
-        LOG.debug("Opening in-memory HBase connection")
+    def open(self):
+        LOG.debug(_("Opening in-memory HBase connection"))
 
     def create_table(self, n, families=None):
         families = families or {}
