@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -18,29 +17,15 @@
 """Simple logging storage backend.
 """
 
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
 from ceilometer.storage import base
 
 LOG = log.getLogger(__name__)
 
 
-class LogStorage(base.StorageEngine):
-    """Log the data
-    """
-
-    def get_connection(self, conf):
-        """Return a Connection instance based on the configuration settings.
-        """
-        return Connection(conf)
-
-
 class Connection(base.Connection):
-    """Base class for storage system connections.
-    """
-
-    def __init__(self, conf):
-        pass
+    """Log the data."""
 
     def upgrade(self):
         pass
@@ -52,7 +37,7 @@ class Connection(base.Connection):
         """Write the data to the backend storage system.
 
         :param data: a dictionary such as returned by
-                     ceilometer.meter.meter_message_from_counter
+                     ceilometer.meter.meter_message_from_counter.
         """
         LOG.info(_('metering data %(counter_name)s for %(resource_id)s: '
                    '%(counter_volume)s')
@@ -61,32 +46,17 @@ class Connection(base.Connection):
                      'counter_volume': data['counter_volume']}))
 
     def clear_expired_metering_data(self, ttl):
-        """Clear expired data from the backend storage system according to the
-        time-to-live.
+        """Clear expired data from the backend storage system.
 
+        Clearing occurs according to the time-to-live.
         :param ttl: Number of seconds to keep records for.
-
         """
         LOG.info(_("Dropping data with TTL %d"), ttl)
 
-    def get_users(self, source=None):
-        """Return an iterable of user id strings.
-
-        :param source: Optional source filter.
-        """
-        return []
-
-    def get_projects(self, source=None):
-        """Return an iterable of project id strings.
-
-        :param source: Optional source filter.
-        """
-        return []
-
     def get_resources(self, user=None, project=None, source=None,
                       start_timestamp=None, start_timestamp_op=None,
                       end_timestamp=None, end_timestamp_op=None,
-                      metaquery={}, resource=None, pagination=None):
+                      metaquery=None, resource=None, pagination=None):
         """Return an iterable of dictionaries containing resource information.
 
         { 'resource_id': UUID of the resource,
@@ -111,7 +81,7 @@ class Connection(base.Connection):
         return []
 
     def get_meters(self, user=None, project=None, resource=None, source=None,
-                   limit=None, metaquery={}, pagination=None):
+                   limit=None, metaquery=None, pagination=None):
         """Return an iterable of dictionaries containing meter information.
 
         { 'name': name of the meter,
@@ -132,7 +102,9 @@ class Connection(base.Connection):
         return []
 
     def get_samples(self, sample_filter):
-        """Return an iterable of samples as created by
+        """Return an iterable of samples.
+
+        Items are created by
         :func:`ceilometer.meter.meter_message_from_counter`.
         """
         return []
@@ -140,8 +112,8 @@ class Connection(base.Connection):
     def get_meter_statistics(self, sample_filter, period=None, groupby=None,
                              aggregate=None):
         """Return a dictionary containing meter statistics.
-        described by the query parameters.
 
+        Meter statistics is described by the query parameters.
         The filter must have a meter value set.
 
         { 'min':
@@ -156,25 +128,5 @@ class Connection(base.Connection):
           'duration_start':
           'duration_end':
           }
-
         """
         return []
-
-    def get_alarms(self, name=None, user=None,
-                   project=None, enabled=None, alarm_id=None, pagination=None):
-        """Yields a lists of alarms that match filters
-        """
-        return []
-
-    def create_alarm(self, alarm):
-        """Create alarm.
-        """
-        return alarm
-
-    def update_alarm(self, alarm):
-        """update alarm
-        """
-        return alarm
-
-    def delete_alarm(self, alarm_id):
-        """Delete an alarm."""
