@@ -470,7 +470,7 @@ class Connection(pymongo_base.Connection):
         )
 
     def clear(self):
-        self.conn.drop_database(self.db)
+        self.conn.drop_database(self.db.name)
         # Connection will be reopened automatically if needed
         self.conn.close()
 
