@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 eNovance <licensing@enovance.com>
+# Copyright 2013 eNovance <licensing@enovance.com>
 #
 # Author: Mehdi Abaakouk <mehdi.abaakouk@enovance.com>
 #         Eoghan Glynn <eglynn@redhat.com>
@@ -19,12 +18,10 @@
 """Base class for tests in ceilometer/alarm/evaluator/
 """
 import mock
-
-from ceilometer.openstack.common import test
-from ceilometer.openstack.common import timeutils
+from oslotest import base
 
 
-class TestEvaluatorBase(test.BaseTestCase):
+class TestEvaluatorBase(base.BaseTestCase):
     def setUp(self):
         super(TestEvaluatorBase, self).setUp()
         self.api_client = mock.Mock()
@@ -32,10 +29,6 @@ class TestEvaluatorBase(test.BaseTestCase):
         self.evaluator = self.EVALUATOR(self.notifier)
         self.prepare_alarms()
 
-    def tearDown(self):
-        super(TestEvaluatorBase, self).tearDown()
-        timeutils.utcnow.override_time = None
-
     @staticmethod
     def prepare_alarms(self):
         self.alarms = []
