@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 eNovance <licensing@enovance.com>
+# Copyright 2013 eNovance <licensing@enovance.com>
 #
 # Authors: Mehdi Abaakouk <mehdi.abaakouk@enovance.com>
 #
@@ -22,9 +21,10 @@ import mock
 import pytz
 import uuid
 
+from oslo.utils import timeutils
+
 from ceilometer.alarm.evaluator import combination
-from ceilometer.openstack.common import timeutils
-from ceilometer.storage import models
+from ceilometer.alarm.storage import models
 from ceilometer.tests.alarm.evaluator import base
 from ceilometerclient import exc
 from ceilometerclient.v2 import alarms
@@ -89,16 +89,16 @@ class TestEvaluate(base.TestEvaluatorBase):
 
     def _combination_transition_reason(self, state, alarm_ids1, alarm_ids2):
         return ([('Transition to %(state)s due to alarms %(alarm_ids)s'
-                ' in state %(state)s')
+                  ' in state %(state)s')
                 % {'state': state, 'alarm_ids': ",".join(alarm_ids1)},
                 ('Transition to %(state)s due to alarms %(alarm_ids)s'
-                ' in state %(state)s')
+                 ' in state %(state)s')
                 % {'state': state, 'alarm_ids': ",".join(alarm_ids2)}],
                 [self._reason_data(alarm_ids1), self._reason_data(alarm_ids2)])
 
     def _combination_remaining_reason(self, state, alarm_ids1, alarm_ids2):
         return ([('Remaining as %(state)s due to alarms %(alarm_ids)s'
-                 ' in state %(state)s')
+                  ' in state %(state)s')
                 % {'state': state, 'alarm_ids': ",".join(alarm_ids1)},
                 ('Remaining as %(state)s due to alarms %(alarm_ids)s'
                  ' in state %(state)s')
@@ -310,7 +310,8 @@ class TestEvaluate(base.TestEvaluatorBase):
 
             self.assertEqual(expected, self.notifier.notify.call_args_list)
 
-    def test_state_change_inside_time_constraint(self):
+    @mock.patch.object(timeutils, 'utcnow')
+    def test_state_change_inside_time_constraint(self, mock_utcnow):
         self._set_all_alarms('insufficient data')
         self.alarms[0].time_constraints = [
             {'name': 'test',
@@ -322,9 +323,9 @@ class TestEvaluate(base.TestEvaluatorBase):
         self.alarms[1].time_constraints = self.alarms[0].time_constraints
         dt = datetime.datetime(2014, 1, 1, 12, 0, 0,
                                tzinfo=pytz.timezone('Europe/Ljubljana'))
+        mock_utcnow.return_value = dt.astimezone(pytz.UTC)
         with mock.patch('ceilometerclient.client.get_client',
                         return_value=self.api_client):
-            timeutils.set_time_override(dt.astimezone(pytz.UTC))
             self.api_client.alarms.get.side_effect = [
                 self._get_alarm('ok'),
                 self._get_alarm('ok'),
@@ -348,7 +349,8 @@ class TestEvaluate(base.TestEvaluatorBase):
                         in zip(self.alarms, reasons, reason_datas)]
             self.assertEqual(expected, self.notifier.notify.call_args_list)
 
-    def test_no_state_change_outside_time_constraint(self):
+    @mock.patch.object(timeutils, 'utcnow')
+    def test_no_state_change_outside_time_constraint(self, mock_utcnow):
         self._set_all_alarms('insufficient data')
         self.alarms[0].time_constraints = [
             {'name': 'test',
@@ -360,9 +362,9 @@ class TestEvaluate(base.TestEvaluatorBase):
         self.alarms[1].time_constraints = self.alarms[0].time_constraints
         dt = datetime.datetime(2014, 1, 1, 15, 0, 0,
                                tzinfo=pytz.timezone('Europe/Ljubljana'))
+        mock_utcnow.return_value = dt.astimezone(pytz.UTC)
         with mock.patch('ceilometerclient.client.get_client',
                         return_value=self.api_client):
-            timeutils.set_time_override(dt.astimezone(pytz.UTC))
             self.api_client.alarms.get.side_effect = [
                 self._get_alarm('ok'),
                 self._get_alarm('ok'),
