@@ -117,7 +117,7 @@ class TestEvaluate(base.TestEvaluatorBase):
             avgs = [self._get_stat('avg', self.alarms[0].rule['threshold'] - v)
                     for v in moves.xrange(5)]
             maxs = [self._get_stat('max', self.alarms[1].rule['threshold'] + v)
-                    for v in moves.xrange(1, 4)]
+                    for v in moves.xrange(1, 5)]
             self.api_client.statistics.list.side_effect = [broken,
                                                            broken,
                                                            avgs,
@@ -149,6 +149,32 @@ class TestEvaluate(base.TestEvaluatorBase):
                 for alarm in self.alarms]
             self.assertEqual(expected, self.notifier.notify.call_args_list)
 
+    def test_less_insufficient_data(self):
+        self._set_all_alarms('ok')
+        with mock.patch('ceilometerclient.client.get_client',
+                        return_value=self.api_client):
+            avgs = [self._get_stat('avg', self.alarms[0].rule['threshold'] - v)
+                    for v in moves.xrange(4)]
+            maxs = [self._get_stat('max', self.alarms[1].rule['threshold'] - v)
+                    for v in moves.xrange(1, 4)]
+            self.api_client.statistics.list.side_effect = [avgs, maxs]
+            self._evaluate_all_alarms()
+            self._assert_all_alarms('insufficient data')
+            expected = [mock.call(alarm.alarm_id, state='insufficient data')
+                        for alarm in self.alarms]
+            update_calls = self.api_client.alarms.set_state.call_args_list
+            self.assertEqual(update_calls, expected)
+            expected = [mock.call(
+                alarm,
+                'ok',
+                ('%d datapoints are unknown'
+                 % alarm.rule['evaluation_periods']),
+                self._reason_data('unknown',
+                                  alarm.rule['evaluation_periods'],
+                                  alarm.rule['threshold'] - 3))
+                for alarm in self.alarms]
+            self.assertEqual(expected, self.notifier.notify.call_args_list)
+
     def test_simple_alarm_trip(self):
         self._set_all_alarms('ok')
         with mock.patch('ceilometerclient.client.get_client',
