@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Julien Danjou <julien@danjou.info>
 #
@@ -20,19 +19,16 @@
 import datetime
 import json
 
-import testscenarios
+from oslo.utils import timeutils
+import webtest
 
-from ceilometer.api import acl
-from ceilometer.api.controllers import v2 as v2_api
-from ceilometer.openstack.common import timeutils
+from ceilometer.api import app
 from ceilometer.publisher import utils
 from ceilometer import sample
-from ceilometer.tests.api.v2 import FunctionalTest
+from ceilometer.tests import api as acl
+from ceilometer.tests.api import v2
 from ceilometer.tests import db as tests_db
 
-
-load_tests = testscenarios.load_tests_apply_scenarios
-
 VALID_TOKEN = '4562138218392831'
 VALID_TOKEN2 = '4562138218392832'
 
@@ -74,7 +70,7 @@ class FakeMemcache(object):
         pass
 
 
-class TestAPIACL(FunctionalTest,
+class TestAPIACL(v2.FunctionalTest,
                  tests_db.MixinTestsWithBackendScenarios):
 
     def setUp(self):
@@ -112,17 +108,19 @@ class TestAPIACL(FunctionalTest,
             self.conn.record_metering_data(msg)
 
     def get_json(self, path, expect_errors=False, headers=None,
-                 q=[], **params):
+                 q=None, **params):
         return super(TestAPIACL, self).get_json(path,
                                                 expect_errors=expect_errors,
                                                 headers=headers,
-                                                q=q,
+                                                q=q or [],
                                                 extra_environ=self.environ,
                                                 **params)
 
     def _make_app(self):
         self.CONF.set_override("cache", "fake.cache", group=acl.OPT_GROUP_NAME)
-        return super(TestAPIACL, self)._make_app(enable_acl=True)
+        file_name = self.path_get('etc/ceilometer/api_paste.ini')
+        self.CONF.set_override("api_paste_config", file_name)
+        return webtest.TestApp(app.load_app())
 
     def test_non_authenticated(self):
         response = self.get_json('/meters', expect_errors=True)
@@ -210,23 +208,8 @@ class TestAPIACL(FunctionalTest,
         self.assertEqual(401, data.status_int)
 
     def test_non_admin_get_events(self):
-
-        # NOTE(herndon): wsme does not handle the  error that is being
-        # raised in by requires_admin dues to the decorator ordering. wsme
-        # does not play nice with other decorators, and so requires_admin
-        # must call wsme.wsexpose, and not the other way arou. The
-        # implication is that I can't look at the status code in the
-        # return value. Work around is to catch the exception here and
-        # verify that the status code is correct.
-
-        try:
-            # Intentionally *not* using assertRaises here so I can look
-            # at the status code of the exception.
-            self.get_json('/event_types', expect_errors=True,
-                          headers={"X-Roles": "Member",
-                                   "X-Auth-Token": VALID_TOKEN2,
-                                   "X-Project-Id": "project-good"})
-        except v2_api.ClientSideError as ex:
-            self.assertEqual(401, ex.code)
-        else:
-            self.fail()
+        data = self.get_json('/event_types', expect_errors=True,
+                             headers={"X-Roles": "Member",
+                                      "X-Auth-Token": VALID_TOKEN2,
+                                      "X-Project-Id": "project-good"})
+        self.assertEqual(401, data.status_int)
