@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -19,29 +18,27 @@
 """
 
 import datetime
-import logging
 
-import testscenarios
+import mock
+from oslo.utils import timeutils
+import six
 import webtest.app
 
-from ceilometer.openstack.common import timeutils
 from ceilometer.publisher import utils
 from ceilometer import sample
-from ceilometer.tests.api.v2 import FunctionalTest
+from ceilometer.tests.api import v2
 from ceilometer.tests import db as tests_db
 
 
-load_tests = testscenarios.load_tests_apply_scenarios
-
-LOG = logging.getLogger(__name__)
-
-
-class TestListEvents(FunctionalTest,
+class TestListEvents(v2.FunctionalTest,
                      tests_db.MixinTestsWithBackendScenarios):
 
     def setUp(self):
         super(TestListEvents, self).setUp()
-        timeutils.utcnow.override_time = datetime.datetime(2014, 2, 11, 16, 42)
+        patcher = mock.patch.object(timeutils, 'utcnow')
+        self.addCleanup(patcher.stop)
+        self.mock_utcnow = patcher.start()
+        self.mock_utcnow.return_value = datetime.datetime(2014, 2, 11, 16, 42)
         self.sample1 = sample.Sample(
             'instance',
             'cumulative',
@@ -88,8 +85,7 @@ class TestListEvents(FunctionalTest,
         data = self.get_json('/meters/instance')
         self.assertEqual(2, len(data))
         for s in data:
-            self.assertEqual(timeutils.utcnow.override_time.isoformat(),
-                             s['recorded_at'])
+            self.assertEqual(timeutils.utcnow().isoformat(), s['recorded_at'])
 
     def test_all_trailing_slash(self):
         data = self.get_json('/meters/instance/')
@@ -177,4 +173,4 @@ class TestListEvents(FunctionalTest,
              ('not_ignored_list', "['returned']"),
              ('tag', 'self.sample'),
              ],
-            list(sorted(sample['resource_metadata'].iteritems())))
+            list(sorted(six.iteritems(sample['resource_metadata']))))
