@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Red Hat, Inc
+# Copyright 2013 Red Hat, Inc
 #
 # Author: Angus Salkeld <asalkeld@redhat.com>
 #
@@ -21,30 +20,28 @@
 import copy
 import datetime
 
-import testscenarios
+import mock
+from oslo.utils import timeutils
+from oslotest import mockpatch
 
-from ceilometer.openstack.common.fixture.mockpatch import PatchObject
-from ceilometer.openstack.common import rpc
-from ceilometer.openstack.common import timeutils
-from ceilometer.tests.api.v2 import FunctionalTest
+from ceilometer.tests.api import v2
 from ceilometer.tests import db as tests_db
 
 
-load_tests = testscenarios.load_tests_apply_scenarios
-
-
-class TestPostSamples(FunctionalTest,
+class TestPostSamples(v2.FunctionalTest,
                       tests_db.MixinTestsWithBackendScenarios):
-
-    def fake_cast(self, context, topic, msg):
-        for s in msg['args']['data']:
-            del s['message_signature']
-        self.published.append((topic, msg))
+    def fake_notifier_sample(self, ctxt, event_type, payload):
+        for m in payload:
+            del m['message_signature']
+        self.published.append(payload)
 
     def setUp(self):
-        super(TestPostSamples, self).setUp()
         self.published = []
-        self.useFixture(PatchObject(rpc, 'cast', side_effect=self.fake_cast))
+        notifier = mock.Mock()
+        notifier.sample.side_effect = self.fake_notifier_sample
+        self.useFixture(mockpatch.Patch('oslo.messaging.Notifier',
+                                        return_value=notifier))
+        super(TestPostSamples, self).setUp()
 
     def test_one(self):
         s1 = [{'counter_name': 'apples',
@@ -56,7 +53,6 @@ class TestPostSamples(FunctionalTest,
                'user_id': 'efd87807-12d2-4b38-9c70-5f5c2ac427ff',
                'resource_metadata': {'name1': 'value1',
                                      'name2': 'value2'}}]
-
         data = self.post_json('/meters/apples/', s1)
 
         # timestamp not given so it is generated.
@@ -67,7 +63,7 @@ class TestPostSamples(FunctionalTest,
         s1[0]['source'] = '%s:openstack' % s1[0]['project_id']
 
         self.assertEqual(s1, data.json)
-        self.assertEqual(s1[0], self.published[0][1]['args']['data'][0])
+        self.assertEqual(s1[0], self.published[0][0])
 
     def test_nested_metadata(self):
         s1 = [{'counter_name': 'apples',
@@ -97,7 +93,7 @@ class TestPostSamples(FunctionalTest,
         # only the published sample should be unwound, not the representation
         # in the API response
         self.assertEqual(s1[0], data.json[0])
-        self.assertEqual(unwound, self.published[0][1]['args']['data'][0])
+        self.assertEqual(unwound, self.published[0][0])
 
     def test_invalid_counter_type(self):
         s1 = [{'counter_name': 'my_counter_name',
@@ -164,6 +160,7 @@ class TestPostSamples(FunctionalTest,
 
     def test_multiple_samples(self):
         """Send multiple samples.
+
         The usecase here is to reduce the chatter and send the counters
         at a slower cadence.
         """
@@ -199,12 +196,12 @@ class TestPostSamples(FunctionalTest,
             c['timestamp'] = timestamp.replace(tzinfo=None).isoformat()
 
             # do the same on the pipeline
-            msg = self.published[0][1]['args']['data'][x]
+            msg = self.published[0][x]
             timestamp = timeutils.parse_isotime(msg['timestamp'])
             msg['timestamp'] = timestamp.replace(tzinfo=None).isoformat()
 
             self.assertEqual(s, c)
-            self.assertEqual(s, self.published[0][1]['args']['data'][x])
+            self.assertEqual(s, self.published[0][x])
 
     def test_missing_mandatory_fields(self):
         """Do not accept posting samples with missing mandatory fields."""
@@ -264,11 +261,13 @@ class TestPostSamples(FunctionalTest,
             s['timestamp'] = data.json[x]['timestamp']
             s.setdefault('resource_metadata', dict())
             self.assertEqual(s, data.json[x])
-            self.assertEqual(s, self.published[0][1]['args']['data'][x])
+            self.assertEqual(s, self.published[0][x])
 
     def test_multiple_samples_multiple_sources(self):
-        """Do accept a single post with some multiples sources
-        with some of them null
+        """Test posting with special conditions.
+
+        Do accept a single post with some multiples sources with some of them
+        null.
         """
         s1 = [{'counter_name': 'my_counter_name',
                'counter_type': 'gauge',
@@ -312,11 +311,10 @@ class TestPostSamples(FunctionalTest,
             s['timestamp'] = data.json[x]['timestamp']
             s.setdefault('resource_metadata', dict())
             self.assertEqual(s, data.json[x])
-            self.assertEqual(s, self.published[0][1]['args']['data'][x])
+            self.assertEqual(s, self.published[0][x])
 
     def test_missing_project_user_id(self):
-        """Ensure missing project & user IDs are defaulted appropriately.
-        """
+        """Ensure missing project & user IDs are defaulted appropriately."""
         s1 = [{'counter_name': 'my_counter_name',
                'counter_type': 'gauge',
                'counter_unit': 'instance',
@@ -349,4 +347,4 @@ class TestPostSamples(FunctionalTest,
             s['project_id'] = project_id
 
             self.assertEqual(s, data.json[x])
-            self.assertEqual(s, self.published[0][1]['args']['data'][x])
+            self.assertEqual(s, self.published[0][x])
