@@ -18,17 +18,17 @@ import datetime
 
 import fixtures
 import mock
+from oslo.utils import timeutils
+from oslotest import base
+from oslotest import mockpatch
 import wsme
 
 from ceilometer.api.controllers import v2 as api
-from ceilometer.openstack.common.fixture.mockpatch import PatchObject
-from ceilometer.openstack.common import test
-from ceilometer.openstack.common import timeutils
 from ceilometer import storage
 from ceilometer.tests import base as tests_base
 
 
-class TestQuery(test.BaseTestCase):
+class TestQuery(base.BaseTestCase):
     def setUp(self):
         super(TestQuery, self).setUp()
         self.useFixture(fixtures.MonkeyPatch(
@@ -143,7 +143,7 @@ class TestQuery(test.BaseTestCase):
         self.assertEqual(expected, query._get_value_as_type())
 
 
-class TestValidateGroupByFields(test.BaseTestCase):
+class TestValidateGroupByFields(base.BaseTestCase):
 
     def test_valid_field(self):
         result = api._validate_groupby_fields(['user_id'])
@@ -175,10 +175,10 @@ class TestValidateGroupByFields(test.BaseTestCase):
 class TestQueryToKwArgs(tests_base.BaseTestCase):
     def setUp(self):
         super(TestQueryToKwArgs, self).setUp()
-        self.useFixture(PatchObject(api, '_sanitize_query',
-                        side_effect=lambda x, y, **z: x))
-        self.useFixture(PatchObject(api, '_verify_query_segregation',
-                        side_effect=lambda x, **z: x))
+        self.useFixture(mockpatch.PatchObject(
+            api, '_sanitize_query', side_effect=lambda x, y, **z: x))
+        self.useFixture(mockpatch.PatchObject(
+            api, '_verify_query_segregation', side_effect=lambda x, **z: x))
 
     def test_sample_filter_single(self):
         q = [api.Query(field='user_id',
@@ -321,3 +321,15 @@ class TestQueryToKwArgs(tests_base.BaseTestCase):
                                           storage.SampleFilter.__init__)
             for o in ['user', 'project', 'resource']:
                 self.assertEqual('fake_%s_id' % o, kwargs.get(o))
+
+    def test_timestamp_validation(self):
+        q = [api.Query(field='timestamp',
+                       op='le',
+                       value='123')]
+
+        exc = self.assertRaises(
+            wsme.exc.InvalidInput,
+            api._query_to_kwargs, q, storage.SampleFilter.__init__)
+        expected_exc = wsme.exc.InvalidInput('timestamp', '123',
+                                             'invalid timestamp format')
+        self.assertEqual(str(expected_exc), str(exc))
