@@ -1,7 +1,6 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network (DreamHost)
+# Copyright 2012 New Dream Network (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -20,15 +19,40 @@
 """
 import functools
 import os.path
+
+import eventlet
+import oslo.messaging.conffixture
+from oslo.utils import timeutils
+from oslotest import base
+from oslotest import mockpatch
 import six
-
 from testtools import testcase
+import webtest
 
-from ceilometer.openstack.common import test
-from ceilometer.openstack.common import timeutils
+import ceilometer
+from ceilometer import messaging
 
 
-class BaseTestCase(test.BaseTestCase):
+class BaseTestCase(base.BaseTestCase):
+    def setup_messaging(self, conf, exchange=None):
+        self.useFixture(oslo.messaging.conffixture.ConfFixture(conf))
+        conf.set_override("notification_driver", "messaging")
+        if not exchange:
+            exchange = 'ceilometer'
+        conf.set_override("control_exchange", exchange)
+
+        # NOTE(sileht): oslo.messaging fake driver uses time.sleep
+        # for task switch, so we need to monkey_patch it
+        # and also ensure the correct exchange have been set
+        eventlet.monkey_patch(time=True)
+
+        # NOTE(sileht): Ensure a new oslo.messaging driver is loaded
+        # between each tests
+        self.transport = messaging.get_transport("fake://", cache=False)
+        self.useFixture(mockpatch.Patch(
+            'ceilometer.messaging.get_transport',
+            return_value=self.transport))
+
     def assertTimestampEqual(self, first, second, msg=None):
         """Checks that two timestamps are equals.
 
@@ -41,6 +65,20 @@ class BaseTestCase(test.BaseTestCase):
             0.0,
             places=5)
 
+    def assertIsEmpty(self, obj):
+        try:
+            if len(obj) != 0:
+                self.fail("%s is not empty" % type(obj))
+        except (TypeError, AttributeError):
+            self.fail("%s doesn't have length" % type(obj))
+
+    def assertIsNotEmpty(self, obj):
+        try:
+            if len(obj) == 0:
+                self.fail("%s is empty" % type(obj))
+        except (TypeError, AttributeError):
+            self.fail("%s doesn't have length" % type(obj))
+
     @staticmethod
     def path_get(project_file=None):
         root = os.path.abspath(os.path.join(os.path.dirname(__file__),
@@ -59,11 +97,9 @@ def _skip_decorator(func):
     def skip_if_not_implemented(*args, **kwargs):
         try:
             return func(*args, **kwargs)
-        except AssertionError:
-            raise
-        except NotImplementedError as e:
+        except ceilometer.NotImplementedError as e:
             raise testcase.TestSkipped(six.text_type(e))
-        except Exception as e:
+        except webtest.app.AppError as e:
             if 'not implemented' in six.text_type(e):
                 raise testcase.TestSkipped(six.text_type(e))
             raise
