@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -18,16 +17,16 @@
 """Tests for ceilometer/agent/manager.py
 """
 import mock
+from oslotest import base
+from oslotest import mockpatch
 
 from ceilometer import agent
 from ceilometer.compute import manager
 from ceilometer import nova_client
-from ceilometer.openstack.common.fixture import mockpatch
-from ceilometer.openstack.common import test
 from ceilometer.tests import agentbase
 
 
-class TestManager(test.BaseTestCase):
+class TestManager(base.BaseTestCase):
 
     @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
     def test_load_plugins(self):
@@ -84,11 +83,11 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
             polling_task = agent.PollingTask(mgr)
             polling_task.poll_and_publish()
 
-    def self_local_instances_default_agent_discovery(self):
+    def test_local_instances_default_agent_discovery(self):
         self.setup_pipeline()
         self.assertEqual(self.mgr.default_discovery, ['local_instances'])
         polling_tasks = self.mgr.setup_polling_tasks()
         self.mgr.interval_task(polling_tasks.get(60))
-        self._verify_discovery_params([None])
+        self._verify_discovery_params([])
         self.assertEqual(set(self.Pollster.resources),
                          set(self.instances))
