@@ -32,7 +32,11 @@ class TestLibvirtInspection(base.BaseTestCase):
 
     def setUp(self):
         super(TestLibvirtInspection, self).setUp()
-        self.instance_name = 'instance-00000001'
+
+        class VMInstance:
+            id = 'ff58e738-12f4-4c58-acde-77617b68da56'
+            name = 'instance-00000001'
+        self.instance = VMInstance
         self.inspector = libvirt_inspector.LibvirtInspector()
         self.inspector.connection = mock.Mock()
         libvirt_inspector.libvirt = mock.Mock()
@@ -64,12 +68,12 @@ class TestLibvirtInspection(base.BaseTestCase):
 
     def test_inspect_cpus(self):
         with contextlib.nested(mock.patch.object(self.inspector.connection,
-                                                 'lookupByName',
+                                                 'lookupByUUIDString',
                                                  return_value=self.domain),
                                mock.patch.object(self.domain, 'info',
                                                  return_value=(0L, 0L, 0L,
                                                                2L, 999999L))):
-                cpu_info = self.inspector.inspect_cpus(self.instance_name)
+                cpu_info = self.inspector.inspect_cpus(self.instance)
                 self.assertEqual(2L, cpu_info.number)
                 self.assertEqual(999999L, cpu_info.time)
 
@@ -139,7 +143,8 @@ class TestLibvirtInspection(base.BaseTestCase):
         interfaceStats = interface_stats.__getitem__
 
         connection = self.inspector.connection
-        with contextlib.nested(mock.patch.object(connection, 'lookupByName',
+        with contextlib.nested(mock.patch.object(connection,
+                                                 'lookupByUUIDString',
                                                  return_value=self.domain),
                                mock.patch.object(self.domain, 'XMLDesc',
                                                  return_value=dom_xml),
@@ -149,7 +154,7 @@ class TestLibvirtInspection(base.BaseTestCase):
                                mock.patch.object(self.domain, 'info',
                                                  return_value=(0L, 0L, 0L,
                                                                2L, 999999L))):
-            interfaces = list(self.inspector.inspect_vnics(self.instance_name))
+            interfaces = list(self.inspector.inspect_vnics(self.instance))
 
             self.assertEqual(3, len(interfaces))
             vnic0, info0 = interfaces[0]
@@ -190,12 +195,13 @@ class TestLibvirtInspection(base.BaseTestCase):
 
     def test_inspect_vnics_with_domain_shutoff(self):
         connection = self.inspector.connection
-        with contextlib.nested(mock.patch.object(connection, 'lookupByName',
+        with contextlib.nested(mock.patch.object(connection,
+                                                 'lookupByUUIDString',
                                                  return_value=self.domain),
                                mock.patch.object(self.domain, 'info',
                                                  return_value=(5L, 0L, 0L,
                                                                2L, 999999L))):
-            interfaces = list(self.inspector.inspect_vnics(self.instance_name))
+            interfaces = list(self.inspector.inspect_vnics(self.instance))
             self.assertEqual(interfaces, [])
 
     def test_inspect_disks(self):
@@ -215,7 +221,7 @@ class TestLibvirtInspection(base.BaseTestCase):
         """
 
         with contextlib.nested(mock.patch.object(self.inspector.connection,
-                                                 'lookupByName',
+                                                 'lookupByUUIDString',
                                                  return_value=self.domain),
                                mock.patch.object(self.domain, 'XMLDesc',
                                                  return_value=dom_xml),
@@ -225,7 +231,7 @@ class TestLibvirtInspection(base.BaseTestCase):
                                mock.patch.object(self.domain, 'info',
                                                  return_value=(0L, 0L, 0L,
                                                                2L, 999999L))):
-                disks = list(self.inspector.inspect_disks(self.instance_name))
+                disks = list(self.inspector.inspect_disks(self.instance))
 
                 self.assertEqual(1, len(disks))
                 disk0, info0 = disks[0]
@@ -237,12 +243,13 @@ class TestLibvirtInspection(base.BaseTestCase):
 
     def test_inspect_disks_with_domain_shutoff(self):
         connection = self.inspector.connection
-        with contextlib.nested(mock.patch.object(connection, 'lookupByName',
+        with contextlib.nested(mock.patch.object(connection,
+                                                 'lookupByUUIDString',
                                                  return_value=self.domain),
                                mock.patch.object(self.domain, 'info',
                                                  return_value=(5L, 0L, 0L,
                                                                2L, 999999L))):
-            disks = list(self.inspector.inspect_disks(self.instance_name))
+            disks = list(self.inspector.inspect_disks(self.instance))
             self.assertEqual(disks, [])
 
 
