@@ -705,30 +705,20 @@ class TestNotificationConverter(ConverterBase):
         e = c.to_event(self.test_notification2)
         self.assertIsNotValidEvent(e, self.test_notification2)
 
+    @mock.patch('ceilometer.event.converter.get_config_file',
+                mock.Mock(return_value=None))
     def test_setup_events_default_config(self):
+        oslo_cfg.CONF.set_override('drop_unmatched_notifications',
+                                   False, group='event')
 
-        def mock_exists(path):
-            return False
+        c = converter.setup_events(self.fake_plugin_mgr)
+        self.assertIsInstance(c, converter.NotificationEventsConverter)
+        self.assertEqual(1, len(c.definitions))
+        self.assertTrue(c.definitions[0].is_catchall)
 
-        def mock_get_config_file():
-            return None
+        oslo_cfg.CONF.set_override('drop_unmatched_notifications',
+                                   True, group='event')
 
-        with mock.patch('ceilometer.event.converter.get_config_file',
-                        mock_get_config_file):
-
-            oslo_cfg.CONF.set_override('drop_unmatched_notifications',
-                                       False, group='event')
-
-            with mock.patch('os.path.exists', mock_exists):
-                c = converter.setup_events(self.fake_plugin_mgr)
-            self.assertIsInstance(c, converter.NotificationEventsConverter)
-            self.assertEqual(1, len(c.definitions))
-            self.assertTrue(c.definitions[0].is_catchall)
-
-            oslo_cfg.CONF.set_override('drop_unmatched_notifications',
-                                       True, group='event')
-
-            with mock.patch('os.path.exists', mock_exists):
-                c = converter.setup_events(self.fake_plugin_mgr)
-            self.assertIsInstance(c, converter.NotificationEventsConverter)
-            self.assertEqual(0, len(c.definitions))
+        c = converter.setup_events(self.fake_plugin_mgr)
+        self.assertIsInstance(c, converter.NotificationEventsConverter)
+        self.assertEqual(0, len(c.definitions))
