@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -17,18 +16,14 @@
 # under the License.
 """Tests for ceilometer/storage/impl_log.py
 """
+from oslotest import base
 
-import mock
-
-from ceilometer.openstack.common import test
 from ceilometer.storage import impl_log
 
 
-class ConnectionTest(test.BaseTestCase):
+class ConnectionTest(base.BaseTestCase):
     def test_get_connection(self):
-        conf = mock.Mock()
-        log_stg = impl_log.LogStorage()
-        conn = log_stg.get_connection(conf)
+        conn = impl_log.Connection(None)
         conn.record_metering_data({'counter_name': 'test',
                                    'resource_id': __name__,
                                    'counter_volume': 1,
