@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -24,27 +23,23 @@
 
 """
 
+from ceilometer.alarm.storage import impl_mongodb as impl_mongodb_alarm
 from ceilometer.storage import base
 from ceilometer.storage import impl_mongodb
+from ceilometer.tests import base as test_base
 from ceilometer.tests import db as tests_db
 from ceilometer.tests.storage import test_storage_scenarios
 
 
-class MongoDBEngineTestBase(tests_db.TestBase):
-    database_connection = tests_db.MongoDBFakeConnectionUrl()
-
-
-class MongoDBConnection(MongoDBEngineTestBase):
+@tests_db.run_with('mongodb')
+class MongoDBConnection(tests_db.TestBase):
     def test_connection_pooling(self):
-        self.assertEqual(self.conn.conn,
-                         impl_mongodb.Connection(self.CONF).conn)
+        test_conn = impl_mongodb.Connection(self.db_manager.url)
+        self.assertEqual(self.conn.conn, test_conn.conn)
 
     def test_replica_set(self):
-        self.CONF.set_override(
-            'connection',
-            str(tests_db.MongoDBFakeConnectionUrl()) + '?replicaSet=foobar',
-            group='database')
-        conn = impl_mongodb.Connection(self.CONF)
+        url = self.db_manager._url + '?replicaSet=foobar'
+        conn = impl_mongodb.Connection(url)
         self.assertTrue(conn.conn)
 
     def test_recurse_sort_keys(self):
@@ -58,10 +53,10 @@ class MongoDBConnection(MongoDBEngineTestBase):
         self.assertEqual(expect, ret)
 
 
-class MongoDBTestMarkerBase(test_storage_scenarios.DBTestBase,
-                            MongoDBEngineTestBase):
-    #NOTE(Fengqian): All these three test case are the same for resource
-    #and meter collection. As to alarm, we will set up in AlarmTestPagination.
+@tests_db.run_with('mongodb')
+class MongoDBTestMarkerBase(test_storage_scenarios.DBTestBase):
+    # NOTE(Fengqian): All these three test case are the same for resource
+    # and meter collection. As to alarm, we will set up in AlarmTestPagination.
     def test_get_marker(self):
         marker_pairs = {'user_id': 'user-id-4'}
         ret = impl_mongodb.Connection._get_marker(self.conn.db.resource,
@@ -87,7 +82,8 @@ class MongoDBTestMarkerBase(test_storage_scenarios.DBTestBase,
             self.assertTrue(True)
 
 
-class IndexTest(MongoDBEngineTestBase):
+@tests_db.run_with('mongodb')
+class IndexTest(tests_db.TestBase):
     def test_meter_ttl_index_absent(self):
         # create a fake index and check it is deleted
         self.conn.db.meter.ensure_index('foo', name='meter_ttl')
@@ -115,12 +111,12 @@ class IndexTest(MongoDBEngineTestBase):
                                                         name='meter_ttl'))
 
 
-class AlarmTestPagination(test_storage_scenarios.AlarmTestBase,
-                          MongoDBEngineTestBase):
+@tests_db.run_with('mongodb')
+class AlarmTestPagination(test_storage_scenarios.AlarmTestBase):
     def test_alarm_get_marker(self):
         self.add_some_alarms()
         marker_pairs = {'name': 'red-alert'}
-        ret = impl_mongodb.Connection._get_marker(self.conn.db.alarm,
+        ret = impl_mongodb.Connection._get_marker(self.alarm_conn.db.alarm,
                                                   marker_pairs=marker_pairs)
         self.assertEqual('test.one', ret['rule']['meter_name'])
 
@@ -128,7 +124,7 @@ class AlarmTestPagination(test_storage_scenarios.AlarmTestBase,
         self.add_some_alarms()
         try:
             marker_pairs = {'name': 'user-id-foo'}
-            ret = impl_mongodb.Connection._get_marker(self.conn.db.alarm,
+            ret = impl_mongodb.Connection._get_marker(self.alarm_conn.db.alarm,
                                                       marker_pairs)
             self.assertEqual('meter_name-foo', ret['rule']['meter_name'])
         except base.NoResultFound:
@@ -138,14 +134,14 @@ class AlarmTestPagination(test_storage_scenarios.AlarmTestBase,
         self.add_some_alarms()
         try:
             marker_pairs = {'user_id': 'me'}
-            ret = impl_mongodb.Connection._get_marker(self.conn.db.alarm,
+            ret = impl_mongodb.Connection._get_marker(self.alarm_conn.db.alarm,
                                                       marker_pairs)
             self.assertEqual('counter-name-foo', ret['rule']['meter_name'])
         except base.MultipleResultsFound:
             self.assertTrue(True)
 
 
-class CapabilitiesTest(MongoDBEngineTestBase):
+class CapabilitiesTest(test_base.BaseTestCase):
     # Check the returned capabilities list, which is specific to each DB
     # driver
 
@@ -179,12 +175,27 @@ class CapabilitiesTest(MongoDBEngineTestBase):
                                                'stddev': True,
                                                'cardinality': True}}
                            },
+            'events': {'query': {'simple': True}}
+        }
+
+        actual_capabilities = impl_mongodb.Connection.get_capabilities()
+        self.assertEqual(expected_capabilities, actual_capabilities)
+
+    def test_alarm_capabilities(self):
+        expected_capabilities = {
             'alarms': {'query': {'simple': True,
                                  'complex': True},
                        'history': {'query': {'simple': True,
                                              'complex': True}}},
-            'events': {'query': {'simple': False}}
         }
 
-        actual_capabilities = self.conn.get_capabilities()
+        actual_capabilities = impl_mongodb_alarm.Connection.get_capabilities()
+        self.assertEqual(expected_capabilities, actual_capabilities)
+
+    def test_storage_capabilities(self):
+        expected_capabilities = {
+            'storage': {'production_ready': True},
+        }
+        actual_capabilities = (impl_mongodb.Connection.
+                               get_storage_capabilities())
         self.assertEqual(expected_capabilities, actual_capabilities)
