@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 New Dream Network, LLC (DreamHost)
+# Copyright 2013 New Dream Network, LLC (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -18,16 +17,19 @@
 
 import datetime
 
-from ceilometer.openstack.common import test
+from oslotest import base as testbase
+
+from ceilometer.alarm.storage import models as alarm_models
+from ceilometer.storage import base
 from ceilometer.storage import models
 
 
-class FakeModel(models.Model):
+class FakeModel(base.Model):
     def __init__(self, arg1, arg2):
-        models.Model.__init__(self, arg1=arg1, arg2=arg2)
+        base.Model.__init__(self, arg1=arg1, arg2=arg2)
 
 
-class ModelTest(test.BaseTestCase):
+class ModelTest(testbase.BaseTestCase):
 
     def test_create_attributes(self):
         m = FakeModel(1, 2)
@@ -77,7 +79,7 @@ class ModelTest(test.BaseTestCase):
                         "time_constraints"]
 
         self.assertEqual(set(alarm_fields),
-                         set(models.Alarm.get_field_names()))
+                         set(alarm_models.Alarm.get_field_names()))
 
     def test_get_field_names_of_alarmchange(self):
         alarmchange_fields = ["event_id", "alarm_id", "type", "detail",
@@ -85,10 +87,10 @@ class ModelTest(test.BaseTestCase):
                               "timestamp"]
 
         self.assertEqual(set(alarmchange_fields),
-                         set(models.AlarmChange.get_field_names()))
+                         set(alarm_models.AlarmChange.get_field_names()))
 
 
-class TestTraitModel(test.BaseTestCase):
+class TestTraitModel(testbase.BaseTestCase):
 
     def test_convert_value(self):
         v = models.Trait.convert_value(
