@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Intel Corp.
+# Copyright 2013 Intel Corp.
 #
 # Author: Yunhong Jiang <yunhong.jiang@intel.com>
 #
@@ -17,8 +16,9 @@
 # under the License.
 
 import abc
-import six
+import collections
 
+import six
 from stevedore import extension
 
 
@@ -67,3 +67,27 @@ class TransformerBase(object):
         :param context: Passed from the data collector.
         """
         return []
+
+
+class Namespace(object):
+    """Encapsulates the namespace.
+
+    Encapsulation is done by wrapping the evaluation of the configured rule.
+    This allows nested dicts to be accessed in the attribute style,
+    and missing attributes to yield false when used in a boolean expression.
+    """
+    def __init__(self, seed):
+        self.__dict__ = collections.defaultdict(lambda: Namespace({}))
+        self.__dict__.update(seed)
+        for k, v in six.iteritems(self.__dict__):
+            if isinstance(v, dict):
+                self.__dict__[k] = Namespace(v)
+
+    def __getattr__(self, attr):
+        return self.__dict__[attr]
+
+    def __getitem__(self, key):
+        return self.__dict__[key]
+
+    def __nonzero__(self):
+        return len(self.__dict__) > 0
