@@ -4,12 +4,16 @@ set -e
 function clean_exit(){
     local error_code="$?"
     rm -rf ${MONGO_DATA}
+    if test -n "$CEILOMETER_TEST_HBASE_URL"
+    then
+            python tools/test_hbase_table_utils.py --clear
+    fi
     kill $(jobs -p)
     return $error_code
 }
 
 # Setup MongoDB test server
-MONGO_DATA=`mktemp -d /tmp/CEILO-MONGODB-XXXXX`
+MONGO_DATA=`mktemp -d CEILO-MONGODB-XXXXX`
 MONGO_PORT=29000
 trap "clean_exit" EXIT
 mkfifo ${MONGO_DATA}/out
@@ -28,6 +32,11 @@ done < ${MONGO_DATA}/out
 # Read the fifo for ever otherwise mongod would block
 cat ${MONGO_DATA}/out > /dev/null &
 export CEILOMETER_TEST_MONGODB_URL="mongodb://localhost:${MONGO_PORT}/ceilometer"
+if test -n "$CEILOMETER_TEST_HBASE_URL"
+then
+    export CEILOMETER_TEST_HBASE_TABLE_PREFIX=$(hexdump -n 16 -v -e '/1 "%02X"' /dev/urandom)
+    python tools/test_hbase_table_utils.py --upgrade
+fi
 
 # Yield execution to venv command
 $*
