@@ -1,7 +1,6 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network (DreamHost)
+# Copyright 2012 New Dream Network (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -21,6 +20,7 @@ from __future__ import print_function
 import sys
 
 from oslo.config import cfg
+import six
 
 from ceilometer import storage
 
@@ -39,7 +39,7 @@ def show_resources(db, args):
         print(u)
         for resource in db.get_resources(user=u):
             print('  %(resource_id)s %(timestamp)s' % resource)
-            for k, v in sorted(resource['metadata'].iteritems()):
+            for k, v in sorted(six.iteritems(resource['metadata'])):
                 print('      %-10s : %s' % (k, v))
             for meter in resource['meter']:
                 totals = db.get_statistics(storage.SampleFilter(
@@ -118,7 +118,7 @@ def main(argv):
         #ceilometer collector by default.
         default_config_files=['/etc/ceilometer/ceilometer.conf'],
     )
-    db = storage.get_connection(cfg.CONF)
+    db = storage.get_connection_from_config(cfg.CONF)
     command = extra_args[0] if extra_args else 'help'
     COMMANDS[command](db, extra_args[1:])
 
